==> theia-0.1.2-py3-none-any.whl: theia/aws/containers/k8s/cluster.py <==
import json
import pulumi

from pulumi_aws import eks
from pulumi.output import Output

from dataclasses import field
from pydantic.dataclasses import dataclass, ConfigDict
from typing import List, Mapping, Optional, Literal

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia.registry import StackRegistry, GlobalTags


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class ClusterVpcArgs:
    cluster_security_group_id: Optional[str | Output[str]] = None
    endpoint_private_access: Optional[bool] = True
    endpoint_public_access: Optional[bool] = True
    public_access_cidrs: Optional[List[str | Output[str]]] = field(
        default_factory=lambda: ["0.0.0.0/0"]
    )
    security_group_ids: Optional[List[str | Output[str]]] = None
    vpc_id: Optional[str | Output[str]] = None

    def __post_init__(self):
        if not self.endpoint_public_access:
            self.public_access_cidrs = None


class K8sCluster:
    def __new__(
        cls,
        resource_name: str,
        role_arn: str,
        version: str,
        subnet_ids: List[str],
        cluster_vpc_args: Optional[ClusterVpcArgs] = ClusterVpcArgs(),
        enabled_cluster_log_types: Optional[
            List[
                Literal[
                    "api", "audit", "authenticator", "controllerManager", "scheduler"
                ]
            ]
        ] = None,
        kms_key_arn: Optional[str] = None,
        default_addons_to_remove: Optional[List[str]] = None,
        resources_to_encrypt: Optional[List[str]] = ["secrets"],
        network_ipv4_cidr: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> eks.Cluster:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = merged_tags | tags

        vpc_args = eks.ClusterVpcConfigArgs(
            subnet_ids=subnet_ids,
            cluster_security_group_id=cluster_vpc_args.cluster_security_group_id,
            endpoint_private_access=cluster_vpc_args.endpoint_private_access,
            endpoint_public_access=cluster_vpc_args.endpoint_public_access,
            public_access_cidrs=cluster_vpc_args.public_access_cidrs,
            security_group_ids=cluster_vpc_args.security_group_ids,
            vpc_id=cluster_vpc_args.vpc_id,
        )

        encryption_args = None
        if kms_key_arn:
            encryption_args = eks.ClusterEncryptionConfigArgs(
                provider=eks.ClusterEncryptionConfigProviderArgs(key_arn=kms_key_arn),
                resources=resources_to_encrypt,
            )

        network_args = None
        if network_ipv4_cidr:
            network_args = eks.ClusterKubernetesNetworkConfigArgs(
                ip_family="ipv4", service_ipv4_cidr=network_ipv4_cidr
            )

        cluster = eks.Cluster(
            resource_name,
            name=resource_name,
            role_arn=role_arn,
            version=version,
            vpc_config=vpc_args,
            kubernetes_network_config=network_args,
            enabled_cluster_log_types=enabled_cluster_log_types,
            encryption_config=encryption_args,
            default_addons_to_removes=default_addons_to_remove,
            tags=merged_tags,
            opts=opts,
        )

        pulumi.export(
            f"eks-cluster---{resource_name}",
            {
                "id": cluster.id,
                "arn": cluster.arn,
                "cluster-id": cluster.cluster_id,
                "endpoint": cluster.endpoint,
                "status": cluster.status,
            },
        )
        return cluster

    @staticmethod
    def import_(stack: str, resource_name: str) -> eks.Cluster:
        stack_ref = StackRegistry.get(stack_name=stack)
        cluster = stack_ref.get_output(name=f"eks-cluster---{resource_name}")
        return eks.Cluster.get(resource_name=resource_name, id=cluster["id"])


class GenerateKubeConfig:
    def __new__(cls, cluster: eks.Cluster) -> str:
        kubeconfig = Output.all(
            cluster.endpoint,
            cluster.certificate_authority.apply(lambda v: v.data),
            cluster.name,
        ).apply(
            lambda args: json.dumps(
                {
                    "apiVersion": "v1",
                    "clusters": [
                        {
                            "cluster": {
                                "server": args[0],
                                "certificate-authority-data": args[1],
                            },
                            "name": "kubernetes",
                        }
                    ],
                    "contexts": [
                        {
                            "context": {
                                "cluster": "kubernetes",
                                "user": "aws",
                            },
                            "name": "aws",
                        }
                    ],
                    "current-context": "aws",
                    "kind": "Config",
                    "users": [
                        {
                            "name": "aws",
                            "user": {
                                "exec": {
                                    "apiVersion": "client.authentication.k8s.io/v1beta1",
                                    "command": "aws-iam-authenticator",
                                    "args": [
                                        "token",
                                        "-i",
                                        args[2],
                                    ],
                                },
                            },
                        }
                    ],
                }
            )
        )
        return kubeconfig

==> theia-0.1.8.31-py3-none-any.whl: theia/aws/containers/k8s/cluster.py <==
import json
import pulumi

from pulumi_aws import eks
from pulumi.output import Output

from dataclasses import field
from pydantic.dataclasses import dataclass, ConfigDict
from typing import List, Mapping, Optional, Literal

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class ClusterVpcArgs:
    cluster_security_group_id: Optional[str | Output[str]] = None
    endpoint_private_access: Optional[bool] = True
    endpoint_public_access: Optional[bool] = True
    public_access_cidrs: Optional[List[str | Output[str]]] = field(
        default_factory=lambda: ["0.0.0.0/0"]
    )
    security_group_ids: Optional[List[str | Output[str]]] = None
    vpc_id: Optional[str | Output[str]] = None

    def __post_init__(self):
        if not self.endpoint_public_access:
            self.public_access_cidrs = None


class K8sCluster:
    def __new__(
        cls,
        resource_name: str,
        role_arn: str,
        version: str,
        subnet_ids: List[str],
        cluster_vpc_args: Optional[ClusterVpcArgs] = ClusterVpcArgs(),
        enabled_cluster_log_types: Optional[
            List[
                Literal[
                    "api", "audit", "authenticator", "controllerManager", "scheduler"
                ]
            ]
        ] = None,
        kms_key_arn: Optional[str] = None,
        default_addons_to_remove: Optional[List[str]] = None,
        resources_to_encrypt: Optional[List[str]] = ["secrets"],
        network_ipv4_cidr: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> eks.Cluster:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = merged_tags | tags

        vpc_args = eks.ClusterVpcConfigArgs(
            subnet_ids=subnet_ids,
            cluster_security_group_id=cluster_vpc_args.cluster_security_group_id,
            endpoint_private_access=cluster_vpc_args.endpoint_private_access,
            endpoint_public_access=cluster_vpc_args.endpoint_public_access,
            public_access_cidrs=cluster_vpc_args.public_access_cidrs,
            security_group_ids=cluster_vpc_args.security_group_ids,
            vpc_id=cluster_vpc_args.vpc_id,
        )

        encryption_args = None
        if kms_key_arn:
            encryption_args = eks.ClusterEncryptionConfigArgs(
                provider=eks.ClusterEncryptionConfigProviderArgs(key_arn=kms_key_arn),
                resources=resources_to_encrypt,
            )

        network_args = None
        if network_ipv4_cidr:
            network_args = eks.ClusterKubernetesNetworkConfigArgs(
                ip_family="ipv4", service_ipv4_cidr=network_ipv4_cidr
            )

        cluster = eks.Cluster(
            resource_name,
            name=resource_name,
            role_arn=role_arn,
            version=version,
            vpc_config=vpc_args,
            kubernetes_network_config=network_args,
            enabled_cluster_log_types=enabled_cluster_log_types,
            encryption_config=encryption_args,
            default_addons_to_removes=default_addons_to_remove,
            tags=merged_tags,
            opts=opts,
        )

        pulumi.export(
            f"eks-cluster---{resource_name}",
            {
                "id": cluster.id,
                "arn": cluster.arn,
                "cluster-id": cluster.cluster_id,
                "endpoint": cluster.endpoint,
                "status": cluster.status,
            },
        )
        return cluster

    @staticmethod
    def import_(stack: str, resource_name: str) -> eks.Cluster:
        stack_ref = StackRegistry.get(stack_name=stack)
        cluster = stack_ref.get_output(name=f"eks-cluster---{resource_name}")
        return eks.Cluster.get(resource_name=resource_name, id=cluster["id"])


class GenerateKubeConfig:
    def __new__(cls, cluster: eks.Cluster) -> str:
        kubeconfig = Output.all(
            cluster.endpoint,
            cluster.certificate_authority.apply(lambda v: v.data),
            cluster.name,
        ).apply(
            lambda args: json.dumps(
                {
                    "apiVersion": "v1",
                    "clusters": [
                        {
                            "cluster": {
                                "server": args[0],
                                "certificate-authority-data": args[1],
                            },
                            "name": "kubernetes",
                        }
                    ],
                    "contexts": [
                        {
                            "context": {
                                "cluster": "kubernetes",
                                "user": "aws",
                            },
                            "name": "aws",
                        }
                    ],
                    "current-context": "aws",
                    "kind": "Config",
                    "users": [
                        {
                            "name": "aws",
                            "user": {
                                "exec": {
                                    "apiVersion": "client.authentication.k8s.io/v1beta1",
                                    "command": "aws-iam-authenticator",
                                    "args": [
                                        "token",
                                        "-i",
                                        args[2],
                                    ],
                                },
                            },
                        }
                    ],
                }
            )
        )
        return kubeconfig
